@@ -7,9 +7,9 @@
   # the private seed during load.
   withPrivateSeed(set.seed(NULL))
 
-  # Create this at the top level, but since the object is from a different
-  # package, we don't want to bake it into the built binary package.
-  restoreCtxStack <<- fastmap::faststack()
+  for (expr in on_load_exprs) {
+    eval(expr, envir = environment(.onLoad))
+  }
 
   # Make sure these methods are available to knitr if shiny is loaded but not
   # attached.
@@ -17,3 +17,11 @@
   s3_register("knitr::knit_print", "shiny.appobj")
   s3_register("knitr::knit_print", "shiny.render.function")
 }
+
+
+on_load_exprs <- list()
+# Register an expression to be evaluated when the package is loaded (in the
+# .onLoad function).
+on_load <- function(expr) {
+  on_load_exprs[[length(on_load_exprs) + 1]] <<- substitute(expr)
+}
